@@ -13,7 +13,7 @@ def copy_and_replace(file_in, file_out, mapping, **kwargs):
     s = file_in.read()
     for find, replace in mapping:
         find = separator + find + separator
-        print('Replacing {0} with {1}').format(find, replace)
+        print('Replacing {0} with {1}'.format(find, replace))
         s = s.replace(find, replace)
     file_out.write(s)
 
